/**
 * Clase abstracta base para los demas elementos fisicos.
 */
public abstract class PhysicsElement {
   private int myId; 
   /**
    * Constructor de elemento fisico
    * @param id identificador del elemento fisico insertado.
    */
   protected PhysicsElement( int id){
      myId = id;
   }
   /**
    * Metodo para retornar el identificador del elemento fisico.
    * @return entero con el identificador del elemento fisico.
    */
   protected int getId() {
      return myId;
   }
   /**
    * Metodo abstracto de calculo del proximo estado del elemento fisico.
    * @param delta_t tiempo de observacion entre estados.
    * @param gravity variable con el valor de la aceleracion de gravedad.
    */
   public abstract void computeNextState(double delta_t, double gravity);
   /**
    * Metodo abstracto de actualizacion del elemento fisico.
    * @param damp incida presencia de amortiguacion.
    */
   public abstract void updateState(boolean damp);
   /**
    * Metodo abstracto de chequeo del estado siguiente del elemento fisico.
    * @param delta_t tiempo de simulacion futura.
    */
   public abstract void checkNext(double delta_t);
   /**
    * Metodo abstracto para obtener la descripcion del elemento fisico.
    * @return retorno de un string con la identificacion del elemento fisico.
    */
   public abstract String getDescription();
   /**
    * Metodo abstracto para obtener el estado del elemento fisico.
    * @return retorno del estado del elemento fisico.
    */public abstract String getState();
}